package com.example.pmulabs.designElem

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.offset
import androidx.compose.foundation.layout.requiredHeight
import androidx.compose.foundation.layout.requiredWidth
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.LazyRow
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Card
import androidx.compose.material3.CardDefaults
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.pmulabs.R
import com.example.pmulabs.models.Article
import com.example.pmulabs.repository.CommentRepository
import com.example.pmulabs.repository.TegRepository
import java.text.SimpleDateFormat

@Composable
fun ArticleItem(article: Article,modifier: Modifier = Modifier,onArticleClick: () -> Unit) {

    val tagRepository= TegRepository()
    val getAllData= tagRepository.getAllData()
    val commRepository= CommentRepository()
    val countComm= commRepository.getCountComment(article.id)
    val formatter = SimpleDateFormat("dd.MM.YY")
    val publishDate=formatter.format(article.publishDate)
    var tagName=""
    getAllData.forEach{teg ->
        if(article.tagId == teg.id){
            tagName=teg.title
        }
    }

    Card(
        colors = CardDefaults.outlinedCardColors(
            containerColor = Color.White,
            contentColor = Color(0xff423a99)
        ),
        border = BorderStroke(3.dp, Color(0xffdbdbf1)),
        modifier = modifier
            .clip(shape = RoundedCornerShape(5.dp))
            .clickable{onArticleClick()}
    ) {
        Box(
            modifier = Modifier
                .requiredWidth(width = 393.dp)
                .requiredHeight(height = 199.dp)
        ) {
            Card(
                colors = CardDefaults.outlinedCardColors(
                    containerColor = Color.White
                ),
                border = BorderStroke(3.dp, Color(0xffdbdbf1)),
                content = {},
                modifier = Modifier
                    .requiredWidth(width = 393.dp)
                    .requiredHeight(height = 199.dp)
                    .clip(shape = RoundedCornerShape(5.dp))
                    .background(color = Color.White)
                    .border(border = BorderStroke(3.dp, Color(0xffdbdbf1)),
                        shape = RoundedCornerShape(5.dp)))
            LazyRow(
                modifier = Modifier
                    .requiredWidth(width = 387.dp)
                    .requiredHeight(height = 199.dp)
            ) {
                item {
                    Image(
                        painter = painterResource(id = R.drawable.image2),
                        contentDescription = "image 2",
                        modifier = Modifier
                            .requiredWidth(width = 180.dp)
                            .requiredHeight(height = 199.dp)
                            .clip(shape = RoundedCornerShape(5.dp))
                            .border(border = BorderStroke(3.dp, Color(0xffdbdbf1)),
                                shape = RoundedCornerShape(5.dp)))
                }
                item {
                    Column(
                        modifier = Modifier
                            .align(alignment = Alignment.TopStart)
                            .offset(x = 5.dp,
                                y = 8.dp)
                            .requiredWidth(width = 201.dp)
                            .requiredHeight(height = 177.dp)
                    ) {
                        LazyColumn(
                            modifier = Modifier
                                .requiredWidth(width = 201.dp)
                                .requiredHeight(height = 150.dp)
                        ) {
                            item {
                                LazyRow(
                                    modifier = Modifier
                                        .requiredWidth(width = 150.dp)
                                        .requiredHeight(height = 20.dp)
                                ) {
                                    item {
                                        Text(
                                            text = "${publishDate}",
                                            color = Color(0xff423a99),
                                            style = TextStyle(
                                                fontSize = 17.sp))
                                    }
                                    item {
                                        Text(
                                            text = "#${tagName}",
                                            color = Color(0xff423a99),
                                            style = TextStyle(
                                                fontSize = 17.sp),
                                            modifier = Modifier
                                                //.align(alignment = Alignment.TopStart)
                                                .offset(x = 12.dp,
                                                    y = 0.dp))
                                    }
                                }
                            }
                            item {
                                Text(
                                    text = "${article.title}",
                                    maxLines=4,
                                    color = Color(0xff423a99),
                                    style = TextStyle(
                                        fontSize = 20.sp,
                                        fontWeight = FontWeight.Bold),
                                    modifier = Modifier
                                        //.align(alignment = Alignment.TopStart)
                                        .offset(x = 0.dp,
                                            y = 15.dp)
                                        .requiredWidth(width = 201.dp)
                                        .requiredHeight(height = 100.dp))
                            }
                        }
                        LazyRow(
                            modifier = Modifier
                                //.align(alignment = Alignment.TopStart)
                                .offset(x = 3.dp,
                                    y = 5.dp)
                                .requiredWidth(width = 80.dp)
                                .requiredHeight(height = 25.dp)
                        ) {
                            item {
                                Row(
                                    modifier = Modifier
                                        .requiredWidth(width = 58.dp)
                                        .requiredHeight(height = 22.dp)
                                ) {
                                    Image(
                                        painter = painterResource(id = R.drawable.ic_comment),
                                        contentDescription = "icon \"heart\"",
                                        modifier = Modifier
                                            .requiredWidth(width = 25.dp)
                                            .requiredHeight(height = 22.dp))
                                    Text(
                                        text = "${countComm}",
                                        color = Color(0xff423a99),
                                        style = TextStyle(
                                            fontSize = 17.sp),
                                        modifier = Modifier
                                            //.align(alignment = Alignment.TopStart)
                                            .offset(x = 5.dp,
                                                y = 1.dp))
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}


