package com.example.pmulabs.screensMobile

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.offset
import androidx.compose.foundation.layout.requiredHeight
import androidx.compose.foundation.layout.requiredWidth
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.material3.HorizontalDivider
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.pmulabs.R
import com.example.pmulabs.basecomponents.navigate.ARTICLE_ARGUMENT_KEY
import com.example.pmulabs.basecomponents.navigate.BackButton
import com.example.pmulabs.designElem.CommentItem
import com.example.pmulabs.repository.ArticleRepository
import com.example.pmulabs.repository.CommentRepository
import com.example.pmulabs.repository.TegRepository
import java.text.SimpleDateFormat

@Composable
fun ArticlePageScreen(navController: NavController,modifier: Modifier = Modifier) {

    var id=navController.currentBackStackEntry?.arguments?.getString(ARTICLE_ARGUMENT_KEY).toString()
    val articleRep=ArticleRepository()
    var article= articleRep.getArticleById("0")
    if (id.toString() != "null") {
        article = articleRep.getArticleById(id)
    }
    val tegRep=TegRepository()
    val teg= tegRep.getTagById(article?.tagId.toString())
    val formatter = SimpleDateFormat("dd.MM.YY")
    val publishDate=formatter.format(article?.publishDate)

    val commRep=CommentRepository()
    val allComm=commRep.getAllData()

    LazyColumn(
        contentPadding= PaddingValues(top=105.dp, bottom = 20.dp,start=15.dp,end=15.dp),
        modifier = modifier
            .requiredWidth(width = 412.dp)
            .requiredHeight(height = 915.dp)
            .background(color = Color.White)
            .fillMaxSize(),
        verticalArrangement = Arrangement.spacedBy(10.dp)
    ) {
        item{
            BackButton(modifier=Modifier
                .clickable { navController.popBackStack()}
                .offset(
                    y=0.dp
                ))
        }
        item {
            Row(
                modifier = Modifier
                    .requiredWidth(width = 245.dp)
                    .requiredHeight(height = 33.dp)
                    .offset(
                        y=0.dp
                    )
            ) {
                Text(
                    text = "${publishDate}",
                    color = Color(0xff423a99),
                    style = MaterialTheme.typography.headlineMedium)
                Text(
                    text = "#${teg.title}",
                    color = Color(0xff423a99),
                    style = MaterialTheme.typography.headlineMedium,
                    modifier = Modifier
                        .offset(x = 60.dp,
                            y = 0.dp))
            }
        }
        item {
            Text(
                text = "${article?.title}",
                color = Color(0xff423a99),
                style = TextStyle(
                    fontSize = 32.sp,
                    fontWeight = FontWeight.Bold),
                modifier = Modifier
                    .offset(x = 10.dp,
                        y = 0.dp)
                    .requiredWidth(width = 395.dp))

        }
        item {
            Image(
                painter = painterResource(id = R.drawable.image3),
                contentDescription = "image 3",
                modifier = Modifier
                    .requiredWidth(width = 412.dp)
                    .requiredHeight(height = 242.dp)
                    .offset(
                        y=0.dp
                    ))
        }
        item {
            Text(
                text = "${article?.text}",
                color = Color(0xff423a99),
                style = MaterialTheme.typography.headlineMedium,
                modifier = Modifier
                    .offset(x = 5.dp,
                        y = 0.dp)
                    .requiredWidth(width = 375.dp))
        }
        item {
            Box(
                modifier = modifier
                    .requiredWidth(width = 412.dp)
                    .requiredHeight(height = 53.dp)
                    .offset(
                        y=0.dp
                    )
            ) {
                Text(
                    text = "Комментарии:",
                    color = Color(0xff423a99),
                    style = TextStyle(
                        fontSize = 32.sp,
                        fontWeight = FontWeight.Bold),
                    modifier = Modifier
                        .align(alignment = Alignment.TopStart)
                        .offset(x = 15.dp,
                            y = 6.dp)
                        .requiredWidth(width = 395.dp)
                        .requiredHeight(height = 43.dp))
                HorizontalDivider(
                    thickness=5.dp,
                    modifier = Modifier
                        .requiredWidth(width = 270.dp)
                        .border(BorderStroke(3.dp, Color(0xff423a99))), color = Color(0xff423a99)
                )
                HorizontalDivider(
                    thickness=5.dp,
                    modifier = Modifier
                        .align(alignment = Alignment.TopStart)
                        .border(BorderStroke(3.dp, Color(0xff423a99)))
                        .offset(x = 142.dp,
                            y = 53.dp)
                        .requiredWidth(width = 270.dp), color = Color(0xff423a99)
                )
            }
        }
        item{
            allComm.forEach{ comm ->
                if(comm.articleId==article.id) {
                    CommentItem(comm = comm, modifier = Modifier.offset( y = 10.dp))
                }
            }
        }
    }
}
