package com.example.pmulabs.screensMobile

import android.util.Log
import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.offset
import androidx.compose.foundation.layout.requiredHeight
import androidx.compose.foundation.layout.requiredSize
import androidx.compose.foundation.layout.requiredWidth
import androidx.compose.foundation.layout.wrapContentHeight
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.pmulabs.R
import com.example.pmulabs.designElem.SharedViewModel
import com.example.pmulabs.repository.UserRepository

@Composable
fun ProfileScreen(navController: NavController, modifier: Modifier = Modifier,sharedViewModel: SharedViewModel) {
    val argument = sharedViewModel.argument.value
    val userRepository =UserRepository()
    var getUser=userRepository.getUserById(argument.toString())
    var getComms=userRepository.getUserComm(argument.toString())
    Log.d("UserId", argument.toString())
    LazyColumn(
        modifier = modifier
            .requiredWidth(width = 412.dp)
            .requiredHeight(height = 915.dp)
            .background(color = Color.White)
    ) {
        item {
            Box(
                modifier = Modifier
                    .offset(
                        x = 106.dp,
                        y = 95.dp
                    )
                    .requiredWidth(width = 200.dp)
                    .requiredHeight(height = 310.dp)
            ) {
                Image(
                    painter = painterResource(id = R.drawable.ixbtcom_colored_logo1),
                    contentDescription = "Ellipse 8",
                    modifier = Modifier
                        .requiredSize(size = 200.dp)
                        .clip(shape = CircleShape))
                Box(
                    modifier = Modifier
                        .align(alignment = Alignment.TopStart)
                        .offset(
                            x = 0.dp,
                            y = 215.dp
                        )
                        .requiredWidth(width = 200.dp)
                        .requiredHeight(height = 44.dp)
                ) {
                    Box(
                        modifier = Modifier
                            .requiredWidth(width = 200.dp)
                            .requiredHeight(height = 44.dp)
                            .clip(shape = RoundedCornerShape(15.dp))
                            .background(color = Color(0xffdbdbf1)))
                    Text(
                        text = "${getUser.nickname}",
                        color = Color(0xff423a99),
                        textAlign = TextAlign.Center,
                        style = TextStyle(
                            fontSize = 17.sp,
                            fontWeight = FontWeight.Bold),
                        modifier = Modifier
                            .requiredWidth(width = 200.dp)
                            .requiredHeight(height = 44.dp)
                            .wrapContentHeight(align = Alignment.CenterVertically))
                }
                Box(
                    modifier = Modifier
                        .align(alignment = Alignment.TopStart)
                        .offset(
                            x = 0.dp,
                            y = 266.dp
                        )
                        .requiredWidth(width = 200.dp)
                        .requiredHeight(height = 44.dp)
                ) {
                    Box(
                        modifier = Modifier
                            .requiredWidth(width = 200.dp)
                            .requiredHeight(height = 44.dp)
                            .clip(shape = RoundedCornerShape(15.dp))
                            .background(color = Color(0xffdbdbf1)))
                    Text(
                        text = "${getUser.email}",
                        color = Color(0xff423a99),
                        textAlign = TextAlign.Center,
                        style = TextStyle(
                            fontSize = 17.sp,
                            fontWeight = FontWeight.Bold),
                        modifier = Modifier
                            .requiredWidth(width = 200.dp)
                            .requiredHeight(height = 44.dp)
                            .wrapContentHeight(align = Alignment.CenterVertically))
                }
            }
        }
        item {
            Box(
                modifier = Modifier
                    .offset(
                        x = 9.dp,
                        y = 120.dp
                    )
                    .requiredWidth(width = 393.dp)
                    .requiredHeight(height = 342.dp)
            ) {
                Box(
                    modifier = Modifier
                        .align(alignment = Alignment.TopStart)
                        .offset(
                            x = 0.dp,
                            y = 27.1240234375.dp
                        )
                        .requiredWidth(width = 393.dp)
                        .requiredHeight(height = 315.dp)
                ) {
                    Box(
                        modifier = Modifier
                            .requiredWidth(width = 393.dp)
                            .requiredHeight(height = 315.dp)
                            .clip(shape = RoundedCornerShape(5.dp))
                            .background(color = Color.White)
                            .border(
                                border = BorderStroke(3.dp, Color(0xffdbdbf1)),
                                shape = RoundedCornerShape(5.dp)
                            )
                    )

                    LazyColumn(

                        contentPadding = PaddingValues(
                            top = 38.dp,
                            bottom = 50.dp,
                            start = 30.dp,
                            end = 30.dp
                        ),
                        verticalArrangement = Arrangement.spacedBy(1.dp)
                    ) {
                        items(items = getComms) { comment ->
                            Text(
                                text = "${comment.text}",
                                color = Color(0xff423a99),
                                style = TextStyle(
                                    fontSize = 15.sp,
                                    fontWeight = FontWeight.Bold
                                ),
                                modifier = Modifier
                                    .align(alignment = Alignment.TopStart)
                            )

                        }

                    }

                }
                Box(
                    modifier = Modifier
                        .requiredWidth(width = 393.dp)
                        .requiredHeight(height = 54.dp)
                ) {
                    Box(
                        modifier = Modifier
                            .requiredWidth(width = 393.dp)
                            .requiredHeight(height = 54.dp)
                            .clip(shape = RoundedCornerShape(15.dp))
                            .background(color = Color(0xff423a99)))
                    Text(
                        text = "Комментарии:",
                        color = Color.White,
                        style = TextStyle(
                            fontSize = 17.sp,
                            fontWeight = FontWeight.Bold),
                        modifier = Modifier
                            .align(alignment = Alignment.TopStart)
                            .offset(
                                x = 24.dp,
                                y = 0.dp
                            )
                            .requiredWidth(width = 210.dp)
                            .requiredHeight(height = 54.dp)
                            .wrapContentHeight(align = Alignment.CenterVertically))
                }
            }
        }
    }
}
